struct TomlFile {
doc: DocumentMut,
path: PathBuf,
}Expand description
A convenience wrapper around a TOML document and the path it was read from
Fields
doc: DocumentMutpath: PathBufImplementations
Sourceimpl TomlFile
impl TomlFile
Sourcefn insert_profile(
&mut self,
profile_str: &str,
value: Item,
) -> Result<(), InsertProfileError>
fn insert_profile( &mut self, profile_str: &str, value: Item, ) -> Result<(), InsertProfileError>
Insert a name as [profile.name]. Creating the [profile] table where necessary and
throwing an error if there exists a conflict
Methods from Deref<Target = DocumentMut>
pub fn as_item(&self) -> &Item
pub fn as_item(&self) -> &Item
Returns a reference to the root item.
pub fn as_item_mut(&mut self) -> &mut Item
pub fn as_item_mut(&mut self) -> &mut Item
Returns a mutable reference to the root item.
pub fn as_table(&self) -> &Table
pub fn as_table(&self) -> &Table
Returns a reference to the root table.
pub fn as_table_mut(&mut self) -> &mut Table
pub fn as_table_mut(&mut self) -> &mut Table
Returns a mutable reference to the root table.
pub fn iter(&self) -> Box<dyn Iterator<Item = (&str, &Item)> + '_>
pub fn iter(&self) -> Box<dyn Iterator<Item = (&str, &Item)> + '_>
Returns an iterator over the root table.
pub fn set_trailing(&mut self, trailing: impl Into<RawString>)
pub fn set_trailing(&mut self, trailing: impl Into<RawString>)
Set whitespace after last element
pub fn trailing(&self) -> &RawString
pub fn trailing(&self) -> &RawString
Whitespace after last element
Methods from Deref<Target = Table>
pub fn get_values(&self) -> Vec<(Vec<&Key>, &Value)>
pub fn get_values(&self) -> Vec<(Vec<&Key>, &Value)>
Get key/values for values that are visually children of this table
For example, this will return dotted keys
pub fn is_implicit(&self) -> bool
pub fn is_implicit(&self) -> bool
If a table has no key/value pairs and implicit, it will not be displayed.
pub fn is_dotted(&self) -> bool
pub fn is_dotted(&self) -> bool
Check if this is a wrapper for dotted keys, rather than a standard table
pub fn position(&self) -> Option<isize>
pub fn position(&self) -> Option<isize>
The position of the Table within the [DocumentMut][crate::DocumentMut].
Returns None if the Table was created manually (i.e. not via parsing)
in which case its position is set automatically. This can be overridden with
[Table::set_position].
pub fn decor(&self) -> &Decor
pub fn decor(&self) -> &Decor
Returns the decor associated with a given key of the table.
pub fn span(&self) -> Option<Range<usize>>
pub fn span(&self) -> Option<Range<usize>>
The location within the original document
This generally requires a [Document][crate::Document].
pub fn iter(&self) -> Box<dyn Iterator<Item = (&str, &Item)> + '_>
pub fn iter(&self) -> Box<dyn Iterator<Item = (&str, &Item)> + '_>
Returns an iterator over all key/value pairs, including empty.
pub fn get<'a>(&'a self, key: &str) -> Option<&'a Item>
pub fn get<'a>(&'a self, key: &str) -> Option<&'a Item>
Returns an optional reference to an item given the key.
pub fn get_key_value<'a>(&'a self, key: &str) -> Option<(&'a Key, &'a Item)>
pub fn get_key_value<'a>(&'a self, key: &str) -> Option<(&'a Key, &'a Item)>
Return references to the key-value pair stored for key, if it is present, else None.
pub fn contains_key(&self, key: &str) -> bool
pub fn contains_key(&self, key: &str) -> bool
Returns true if the table contains an item with the given key.
pub fn contains_table(&self, key: &str) -> bool
pub fn contains_table(&self, key: &str) -> bool
Returns true if the table contains a table with the given key.
pub fn contains_value(&self, key: &str) -> bool
pub fn contains_value(&self, key: &str) -> bool
Returns true if the table contains a value with the given key.
pub fn contains_array_of_tables(&self, key: &str) -> bool
pub fn contains_array_of_tables(&self, key: &str) -> bool
Returns true if the table contains an array of tables with the given key.